@@ -4,7 +4,7 @@ class Exception(object):
 
 class object():
     def __init__(self): pass
-    def __new__(self): pass
+    def __new__(cls): pass
     def __del__(self): pass
     def __repr__(self): pass
     def __str__(self): pass
@@ -99,7 +99,6 @@ class object():
 class basestring():
     pass
 
-@TypeContainer
 class list():
     """! TypeContainer !"""
     def __init__(self, items):
@@ -135,22 +134,31 @@ class list():
 
 class _io_TextIOWrapper():
     def close(self,): return None
+    def detach(self): return self # Not quite
     def flush(self,): return None
-    def fileno(self,): return None
+    def fileno(self,): return 0
     def isatty(self,): return True
     def next(self,): return None
     def read(self,size = 0): return ""
+    def readable(self): return True
     def readline(self,size = 0): return ""
     def readlines(self,sizehint = 0): return [""]
-    def xreadlines(self,): return None
     def seek(self,offset, whence = 0): return None
-    def tell(self,): return None
-    def truncate(self,size = 0): return None
+    def seekable(self): return True
+    def tell(self,): return 0
+    def truncate(self,size = 0): return 0
     def write(self,string): return None
+    def writable(self): return True
     def writelines(self,sequence): return None
+    def __iter__(self): return self
+    def __next__(self): return ""
+    def __enter__(self): return self
+    buffer = _io_TextIOWrapper() # Not quite
     closed = True
+    encoding = ""
     errors = None
-    mode = None
+    line_buffering = True
+    mode = ""
     name = ""
     newlines = ""
     softspace = True
@@ -212,6 +220,9 @@ class str():
         pass
     def __mod__(self, modulo):
         return str()
+    def __getitem__(self): return ""
+    def __iter__(self): return self
+    def __next__(self): return ""
     def replace(self,before, after): return ""
     def capitalize(self,): return ""
     def center(self,width, fillchar = None): return ""
@@ -233,12 +244,12 @@ class str():
     def ljust(self,width, fillchar = ""): return ""
     def lower(self,): return ""
     def lstrip(self,chars = ""): return ""
-    def partition(self,seperator): return (self,"", "", "")
+    def partition(self,seperator): return ("", "", "")
     def replace(self,old, new, count = 0): return ""
     def rfind(self,substring, start = 0, end = 0): return 0
     def rindex(self,substring, start = 0, end = 0): return 0
     def rjust(self,width, fillchar = ""): return ""
-    def rpartition(self,seperator): return (self,"", "", "")
+    def rpartition(self,seperator): return ("", "", "")
     def rsplit(self,seperator = "", maxsplit = 0): return []
     def rstrip(self,chars = ""): return ""
     def split(self,seperator = "", maxsplit = 0): return ["string"]
@@ -278,101 +289,106 @@ class complex():
     def __div__(self, other): return complex()
     def __mod__(self, other): return complex()
 
-class BaseException():
+class BaseException:
     args = ()
+    __cause__ = BaseException
+    __context__ = BaseException
+    __traceback__ = TracebackType
+    def __init__(self, *args): ...
+    def with_traceback(self, tb): return self
 
-class NameError(BaseException):
-    pass
-class AttributeError(BaseException):
-    pass
-class IndexError(BaseException):
-    pass
-class IOError(BaseException):
-    pass
-class StandardError(BaseException):
-    pass
-class Exception(BaseException):
-    pass
-class StopIteration(BaseException):
-    pass
-class StopAsyncIteration(BaseException):
-    pass
-class BufferError(BaseException):
-    pass
-class LookupError(BaseException):
-    pass
-class EnvironmentError(BaseException):
-    pass
-class AssertionError(BaseException):
-    pass
-class EOFError(BaseException):
-    pass
-class FloatingPointError(BaseException):
-    pass
-class GeneratorExit(BaseException):
-    pass
-class ImportError(BaseException):
-    pass
-class KeyError(BaseException):
-    pass
-class MemoryError(BaseException):
-    pass
-class NotImplementedError(BaseException):
-    pass
-class OSError(BaseException):
-    pass
-class OverflowError(BaseException):
-    pass
-class ReferenceError(BaseException):
-    pass
-class RuntimeError(BaseException):
-    pass
-class StopIteration(BaseException):
-    pass
-class SyntaxError(BaseException):
-    pass
-class IndentationError(BaseException):
-    pass
-class TabError(BaseException):
-    pass
-class SystemError(BaseException):
-    pass
+class GeneratorExit(BaseException): ...
+class KeyboardInterrupt(BaseException): ...
 class SystemExit(BaseException):
-    pass
-class TypeError(BaseException):
-    pass
-class UnboundLocalError(BaseException):
-    pass
-class UnicodeError(BaseException):
-    pass
-class UnicodeEncodeError(BaseException):
-    pass
-class UnicodeDecodeError(BaseException):
-    pass
-class UnicodeTranslateError(BaseException):
-    pass
-class ValueError(BaseException):
-    pass
-class ZeroDivisionError(BaseException):
-    pass
-class Warning():
-    pass
-class UserWarning(Warning):
-    pass
-class DeprecationWarning(Warning):
-    pass
-class KeyboardInterrupt(Exception):
-    pass
-class PendingDeprecationWarning(Warning):
-    pass
-class RuntimeWarning(Warning):
-    pass
-class FutureWarning(Warning):
-    pass
-class ImportWarning(Warning):
-    pass
-class UnicodeWarning(Warning):
-    pass
+    code = 0
+class Exception(BaseException): ...
+class ArithmeticError(Exception): ...
+class EnvironmentError(Exception):
+    errno = 0
+    strerror = ""
+    filename = ""
+class LookupError(Exception): ...
+class RuntimeError(Exception): ...
+class ValueError(Exception): ...
+class AssertionError(Exception): ...
+class AttributeError(Exception): ...
+class BufferError(Exception): ...
+class EOFError(Exception): ...
+class FloatingPointError(ArithmeticError): ...
+class IOError(EnvironmentError): ...
+class ImportError(Exception): ...
+class IndexError(LookupError): ...
+class KeyError(LookupError): ...
+class MemoryError(Exception): ...
+class NameError(Exception): ...
+class NotImplementedError(RuntimeError): ...
+class OSError(EnvironmentError): ...
+class BlockingIOError(OSError):
+    characters_written = 0
+class ChildProcessError(OSError): ...
+class ConnectionError(OSError): ...
+class BrokenPipeError(ConnectionError): ...
+class ConnectionAbortedError(ConnectionError): ...
+class ConnectionRefusedError(ConnectionError): ...
+class ConnectionResetError(ConnectionError): ...
+class FileExistsError(OSError): ...
+class FileNotFoundError(OSError): ...
+class InterruptedError(OSError): ...
+class IsADirectoryError(OSError): ...
+class NotADirectoryError(OSError): ...
+class PermissionError(OSError): ...
+class ProcessLookupError(OSError): ...
+class TimeoutError(OSError): ...
+class WindowsError(OSError):
+    winerror = 0
+class OverflowError(ArithmeticError): ...
+class ReferenceError(Exception): ...
+class StopIteration(Exception):
+    value = ...  # type: Any
+class StopAsyncIteration(Exception):
+    value = ...  # type: Any
+class RecursionError(RuntimeError): ...
+class SyntaxError(Exception):
+    msg = ""
+    lineno = 0
+    offset = 0
+    text = ""
+class IndentationError(SyntaxError): ...
+class TabError(IndentationError): ...
+class SystemError(Exception): ...
+class TypeError(Exception): ...
+class UnboundLocalError(NameError): ...
+class UnicodeError(ValueError): ...
+class UnicodeDecodeError(UnicodeError):
+    encoding = ""
+    object = b""
+    start = 0
+    end = 0
+    reason = ""
+    def __init__(self, __encoding: str, __object: bytes,
+                 __start: int, __end: int, __reason: str): ...
+class UnicodeEncodeError(UnicodeError):
+    encoding = ""
+    object = ""
+    start = 0
+    end = 0
+    reason = ""
+    def __init__(self, __encoding: str, __object: str,
+                 __start: int, __end: int, __reason: str): ...
+class UnicodeTranslateError(UnicodeError): ...
+class ZeroDivisionError(ArithmeticError): ...
+
+class Warning(Exception): ...
+class UserWarning(Warning): ...
+class DeprecationWarning(Warning): ...
+class SyntaxWarning(Warning): ...
+class RuntimeWarning(Warning): ...
+class FutureWarning(Warning): ...
+class PendingDeprecationWarning(Warning): ...
+class ImportWarning(Warning): ...
+class UnicodeWarning(Warning): ...
+class BytesWarning(Warning): ...
+class ResourceWarning(Warning): ...
 
 class tuple():
     """! IndexedTypeContainer !"""
@@ -382,6 +398,9 @@ class tuple():
 class bytes:
     def __init__(self, data):
         pass
+    def __getitem__(self, key): return int()
+    def __iter__(self): return self
+    def __next__(self): return int()
     def capitalize(self): return bytes()
     def center(self): return bytes()
     def count(self): return int()
@@ -423,7 +442,7 @@ class bytes:
 
 class set():
     """! TypeContainer !"""
-    def __init__(self, objects):
+    def __init__(self, iterable):
         """! returnContentEqualsContentOf ! 0"""
         pass
     def len(self): return 0
@@ -445,6 +464,21 @@ class set():
     def pop(self): pass
     def clear(self): pass
 
+class frozenset():
+    """! TypeContainer !"""
+    def __init__(self, iterable):
+        """! returnContentEqualsContentOf ! 0"""
+        pass
+    def len(self): return 0
+    def isdisjoint(self, other): return True
+    def issubset(self, other): return True
+    def issuperset(self, other): return True
+    def union(self, other, *others): return set()
+    def intersection(self, other, *others): return set()
+    def difference(self, other, *others): return set()
+    def symmetric_difference(self, other): return set()
+    def copy(self): return set()
+
 def abs(x):
     """ Return the absolute value of a number. The argument may be a plain or long integer or a floating point number. If the argument is a complex number, its magnitude is returned."""
     return 0
@@ -509,9 +543,6 @@ def float(x = 0):
 def format(value, format_spec = None):
     """Convert a value to a “formatted” representation, as controlled by format_spec."""
     return ""
-def frozenset(iterable = None):
-    """Return a new frozenset object, optionally with elements taken from iterable."""
-    return set()
 def getattr(obj, name, default = None):
     """Return the value of the named attribute of object. name must be a string."""
     return None
@@ -531,8 +562,16 @@ def id(obj):
     """Return the “identity” of an object. This is an integer (or long integer) which is guaranteed to be unique and constant for this object during its lifetime. Two objects with non-overlapping lifetimes may have the same id() value."""
     return 0
 def input(prompt = None):
-    """Equivalent to eval(raw_input(prompt))."""
-    return None
+    """
+    Read a string from standard input. The trailing newline is stripped.
+
+    The prompt string, if given, is printed to standard output without a
+    trailing newline before reading input.
+
+    If the user hits EOF (*nix: Ctrl-D, Windows: Ctrl-Z+Return), raise EOFError.
+    On *nix systems, readline is used if available.
+    """
+    return ""
 def isinstance(obj, cls):
     """Return true if the object argument is an instance of the classinfo argument, or of a (direct, indirect or virtual) subclass thereof."""
     return True
@@ -585,9 +624,6 @@ def property(fget = 0, fset = 0, fdel = 0, doc = 0):
 def range(start = 0, stop = 0, step = 0):
     """This is a versatile function to create lists containing arithmetic progressions. It is most often used in for loops. The arguments must be plain integers."""
     return [0]
-def raw_input(prompt = ""):
-    """ The function then reads a line from input, converts it to a string (stripping a trailing newline), and returns that."""
-    return ""
 def reduce(function, iterable, init = None):
     """Apply function of two arguments cumulatively to the items of iterable, from left to right, so as to reduce the iterable to a single value."""
     return None
